Class: Google::Apis::BigquerydatatransferV1::BigQueryDataTransferService
- Inherits:
-
Core::BaseService
- Object
- Core::BaseService
- Google::Apis::BigquerydatatransferV1::BigQueryDataTransferService
- Defined in:
- lib/google/apis/bigquerydatatransfer_v1/service.rb
Overview
BigQuery Data Transfer API
Schedule queries or transfer external data from SaaS applications to Google BigQuery on a regular basis.
Constant Summary collapse
- DEFAULT_ENDPOINT_TEMPLATE =
"https://bigquerydatatransfer.$UNIVERSE_DOMAIN$/"
Instance Attribute Summary collapse
-
#key ⇒ String
API key.
-
#quota_user ⇒ String
Available to use for quota purposes for server-side applications.
Instance Method Summary collapse
-
#check_project_data_source_valid_creds(name, check_valid_creds_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigquerydatatransferV1::CheckValidCredsResponse
Returns true if valid credentials exist for the given data source and requesting user.
-
#check_project_location_data_source_valid_creds(name, check_valid_creds_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigquerydatatransferV1::CheckValidCredsResponse
Returns true if valid credentials exist for the given data source and requesting user.
-
#create_project_location_transfer_config(parent, transfer_config_object = nil, authorization_code: nil, service_account_name: nil, version_info: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigquerydatatransferV1::TransferConfig
Creates a new data transfer configuration.
-
#create_project_transfer_config(parent, transfer_config_object = nil, authorization_code: nil, service_account_name: nil, version_info: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigquerydatatransferV1::TransferConfig
Creates a new data transfer configuration.
-
#delete_project_location_transfer_config(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigquerydatatransferV1::Empty
Deletes a data transfer configuration, including any associated transfer runs and logs.
-
#delete_project_location_transfer_config_run(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigquerydatatransferV1::Empty
Deletes the specified transfer run.
-
#delete_project_transfer_config(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigquerydatatransferV1::Empty
Deletes a data transfer configuration, including any associated transfer runs and logs.
-
#delete_project_transfer_config_run(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigquerydatatransferV1::Empty
Deletes the specified transfer run.
-
#enroll_location_data_sources(name, enroll_data_sources_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigquerydatatransferV1::Empty
Enroll data sources in a user project.
-
#enroll_project_data_sources(name, enroll_data_sources_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigquerydatatransferV1::Empty
Enroll data sources in a user project.
-
#get_project_data_source(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigquerydatatransferV1::DataSource
Retrieves a supported data source and returns its settings.
-
#get_project_location(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigquerydatatransferV1::Location
Gets information about a location.
-
#get_project_location_data_source(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigquerydatatransferV1::DataSource
Retrieves a supported data source and returns its settings.
-
#get_project_location_transfer_config(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigquerydatatransferV1::TransferConfig
Returns information about a data transfer config.
-
#get_project_location_transfer_config_run(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigquerydatatransferV1::TransferRun
Returns information about the particular transfer run.
-
#get_project_location_transfer_config_transfer_resource(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigquerydatatransferV1::TransferResource
Returns a transfer resource.
-
#get_project_transfer_config(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigquerydatatransferV1::TransferConfig
Returns information about a data transfer config.
-
#get_project_transfer_config_run(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigquerydatatransferV1::TransferRun
Returns information about the particular transfer run.
-
#get_project_transfer_config_transfer_resource(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigquerydatatransferV1::TransferResource
Returns a transfer resource.
-
#initialize ⇒ BigQueryDataTransferService
constructor
A new instance of BigQueryDataTransferService.
-
#list_project_data_sources(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigquerydatatransferV1::ListDataSourcesResponse
Lists supported data sources and returns their settings.
-
#list_project_location_data_sources(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigquerydatatransferV1::ListDataSourcesResponse
Lists supported data sources and returns their settings.
-
#list_project_location_transfer_config_run_transfer_logs(parent, message_types: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigquerydatatransferV1::ListTransferLogsResponse
Returns log messages for the transfer run.
-
#list_project_location_transfer_config_runs(parent, page_size: nil, page_token: nil, run_attempt: nil, states: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigquerydatatransferV1::ListTransferRunsResponse
Returns information about running and completed transfer runs.
-
#list_project_location_transfer_config_transfer_resources(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigquerydatatransferV1::ListTransferResourcesResponse
Returns information about transfer resources.
-
#list_project_location_transfer_configs(parent, data_source_ids: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigquerydatatransferV1::ListTransferConfigsResponse
Returns information about all transfer configs owned by a project in the specified location.
-
#list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigquerydatatransferV1::ListLocationsResponse
Lists information about the supported locations for this service.
-
#list_project_transfer_config_run_transfer_logs(parent, message_types: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigquerydatatransferV1::ListTransferLogsResponse
Returns log messages for the transfer run.
-
#list_project_transfer_config_runs(parent, page_size: nil, page_token: nil, run_attempt: nil, states: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigquerydatatransferV1::ListTransferRunsResponse
Returns information about running and completed transfer runs.
-
#list_project_transfer_config_transfer_resources(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigquerydatatransferV1::ListTransferResourcesResponse
Returns information about transfer resources.
-
#list_project_transfer_configs(parent, data_source_ids: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigquerydatatransferV1::ListTransferConfigsResponse
Returns information about all transfer configs owned by a project in the specified location.
-
#patch_project_location_transfer_config(name, transfer_config_object = nil, authorization_code: nil, service_account_name: nil, update_mask: nil, version_info: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigquerydatatransferV1::TransferConfig
Updates a data transfer configuration.
-
#patch_project_transfer_config(name, transfer_config_object = nil, authorization_code: nil, service_account_name: nil, update_mask: nil, version_info: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigquerydatatransferV1::TransferConfig
Updates a data transfer configuration.
-
#schedule_project_location_transfer_config_runs(parent, schedule_transfer_runs_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigquerydatatransferV1::ScheduleTransferRunsResponse
Creates transfer runs for a time range [start_time, end_time].
-
#schedule_project_transfer_config_runs(parent, schedule_transfer_runs_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigquerydatatransferV1::ScheduleTransferRunsResponse
Creates transfer runs for a time range [start_time, end_time].
-
#start_project_location_transfer_config_manual_runs(parent, start_manual_transfer_runs_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigquerydatatransferV1::StartManualTransferRunsResponse
Manually initiates transfer runs.
-
#start_project_transfer_config_manual_runs(parent, start_manual_transfer_runs_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigquerydatatransferV1::StartManualTransferRunsResponse
Manually initiates transfer runs.
-
#unenroll_location_data_sources(name, unenroll_data_sources_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigquerydatatransferV1::Empty
Unenroll data sources in a user project.
Constructor Details
#initialize ⇒ BigQueryDataTransferService
Returns a new instance of BigQueryDataTransferService.
48 49 50 51 52 53 |
# File 'lib/google/apis/bigquerydatatransfer_v1/service.rb', line 48 def initialize super(DEFAULT_ENDPOINT_TEMPLATE, '', client_name: 'google-apis-bigquerydatatransfer_v1', client_version: Google::Apis::BigquerydatatransferV1::GEM_VERSION) @batch_path = 'batch' end |
Instance Attribute Details
#key ⇒ String
Returns API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
41 42 43 |
# File 'lib/google/apis/bigquerydatatransfer_v1/service.rb', line 41 def key @key end |
#quota_user ⇒ String
Returns Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
46 47 48 |
# File 'lib/google/apis/bigquerydatatransfer_v1/service.rb', line 46 def quota_user @quota_user end |
Instance Method Details
#check_project_data_source_valid_creds(name, check_valid_creds_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigquerydatatransferV1::CheckValidCredsResponse
Returns true if valid credentials exist for the given data source and requesting user.
120 121 122 123 124 125 126 127 128 129 130 |
# File 'lib/google/apis/bigquerydatatransfer_v1/service.rb', line 120 def check_project_data_source_valid_creds(name, check_valid_creds_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+name}:checkValidCreds', ) command.request_representation = Google::Apis::BigquerydatatransferV1::CheckValidCredsRequest::Representation command.request_object = check_valid_creds_request_object command.response_representation = Google::Apis::BigquerydatatransferV1::CheckValidCredsResponse::Representation command.response_class = Google::Apis::BigquerydatatransferV1::CheckValidCredsResponse command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#check_project_location_data_source_valid_creds(name, check_valid_creds_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigquerydatatransferV1::CheckValidCredsResponse
Returns true if valid credentials exist for the given data source and requesting user.
395 396 397 398 399 400 401 402 403 404 405 |
# File 'lib/google/apis/bigquerydatatransfer_v1/service.rb', line 395 def check_project_location_data_source_valid_creds(name, check_valid_creds_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+name}:checkValidCreds', ) command.request_representation = Google::Apis::BigquerydatatransferV1::CheckValidCredsRequest::Representation command.request_object = check_valid_creds_request_object command.response_representation = Google::Apis::BigquerydatatransferV1::CheckValidCredsResponse::Representation command.response_class = Google::Apis::BigquerydatatransferV1::CheckValidCredsResponse command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_project_location_transfer_config(parent, transfer_config_object = nil, authorization_code: nil, service_account_name: nil, version_info: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigquerydatatransferV1::TransferConfig
Creates a new data transfer configuration.
540 541 542 543 544 545 546 547 548 549 550 551 552 553 |
# File 'lib/google/apis/bigquerydatatransfer_v1/service.rb', line 540 def create_project_location_transfer_config(parent, transfer_config_object = nil, authorization_code: nil, service_account_name: nil, version_info: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+parent}/transferConfigs', ) command.request_representation = Google::Apis::BigquerydatatransferV1::TransferConfig::Representation command.request_object = transfer_config_object command.response_representation = Google::Apis::BigquerydatatransferV1::TransferConfig::Representation command.response_class = Google::Apis::BigquerydatatransferV1::TransferConfig command.params['parent'] = parent unless parent.nil? command.query['authorizationCode'] = unless .nil? command.query['serviceAccountName'] = service_account_name unless service_account_name.nil? command.query['versionInfo'] = version_info unless version_info.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_project_transfer_config(parent, transfer_config_object = nil, authorization_code: nil, service_account_name: nil, version_info: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigquerydatatransferV1::TransferConfig
Creates a new data transfer configuration.
1145 1146 1147 1148 1149 1150 1151 1152 1153 1154 1155 1156 1157 1158 |
# File 'lib/google/apis/bigquerydatatransfer_v1/service.rb', line 1145 def create_project_transfer_config(parent, transfer_config_object = nil, authorization_code: nil, service_account_name: nil, version_info: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+parent}/transferConfigs', ) command.request_representation = Google::Apis::BigquerydatatransferV1::TransferConfig::Representation command.request_object = transfer_config_object command.response_representation = Google::Apis::BigquerydatatransferV1::TransferConfig::Representation command.response_class = Google::Apis::BigquerydatatransferV1::TransferConfig command.params['parent'] = parent unless parent.nil? command.query['authorizationCode'] = unless .nil? command.query['serviceAccountName'] = service_account_name unless service_account_name.nil? command.query['versionInfo'] = version_info unless version_info.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_transfer_config(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigquerydatatransferV1::Empty
Deletes a data transfer configuration, including any associated transfer runs and logs.
580 581 582 583 584 585 586 587 588 |
# File 'lib/google/apis/bigquerydatatransfer_v1/service.rb', line 580 def delete_project_location_transfer_config(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1/{+name}', ) command.response_representation = Google::Apis::BigquerydatatransferV1::Empty::Representation command.response_class = Google::Apis::BigquerydatatransferV1::Empty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_transfer_config_run(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigquerydatatransferV1::Empty
Deletes the specified transfer run.
856 857 858 859 860 861 862 863 864 |
# File 'lib/google/apis/bigquerydatatransfer_v1/service.rb', line 856 def delete_project_location_transfer_config_run(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1/{+name}', ) command.response_representation = Google::Apis::BigquerydatatransferV1::Empty::Representation command.response_class = Google::Apis::BigquerydatatransferV1::Empty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_transfer_config(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigquerydatatransferV1::Empty
Deletes a data transfer configuration, including any associated transfer runs and logs.
1185 1186 1187 1188 1189 1190 1191 1192 1193 |
# File 'lib/google/apis/bigquerydatatransfer_v1/service.rb', line 1185 def delete_project_transfer_config(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1/{+name}', ) command.response_representation = Google::Apis::BigquerydatatransferV1::Empty::Representation command.response_class = Google::Apis::BigquerydatatransferV1::Empty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_transfer_config_run(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigquerydatatransferV1::Empty
Deletes the specified transfer run.
1461 1462 1463 1464 1465 1466 1467 1468 1469 |
# File 'lib/google/apis/bigquerydatatransfer_v1/service.rb', line 1461 def delete_project_transfer_config_run(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1/{+name}', ) command.response_representation = Google::Apis::BigquerydatatransferV1::Empty::Representation command.response_class = Google::Apis::BigquerydatatransferV1::Empty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#enroll_location_data_sources(name, enroll_data_sources_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigquerydatatransferV1::Empty
Enroll data sources in a user project. This allows users to create transfer configurations for these data sources. They will also appear in the ListDataSources RPC and as such, will appear in the BigQuery UI, and the documents can be found in the public guide for BigQuery Web UI and Data Transfer Service.
234 235 236 237 238 239 240 241 242 243 244 |
# File 'lib/google/apis/bigquerydatatransfer_v1/service.rb', line 234 def enroll_location_data_sources(name, enroll_data_sources_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+name}:enrollDataSources', ) command.request_representation = Google::Apis::BigquerydatatransferV1::EnrollDataSourcesRequest::Representation command.request_object = enroll_data_sources_request_object command.response_representation = Google::Apis::BigquerydatatransferV1::Empty::Representation command.response_class = Google::Apis::BigquerydatatransferV1::Empty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#enroll_project_data_sources(name, enroll_data_sources_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigquerydatatransferV1::Empty
Enroll data sources in a user project. This allows users to create transfer configurations for these data sources. They will also appear in the ListDataSources RPC and as such, will appear in the BigQuery UI, and the documents can be found in the public guide for BigQuery Web UI and Data Transfer Service.
82 83 84 85 86 87 88 89 90 91 92 |
# File 'lib/google/apis/bigquerydatatransfer_v1/service.rb', line 82 def enroll_project_data_sources(name, enroll_data_sources_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+name}:enrollDataSources', ) command.request_representation = Google::Apis::BigquerydatatransferV1::EnrollDataSourcesRequest::Representation command.request_object = enroll_data_sources_request_object command.response_representation = Google::Apis::BigquerydatatransferV1::Empty::Representation command.response_class = Google::Apis::BigquerydatatransferV1::Empty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_data_source(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigquerydatatransferV1::DataSource
Retrieves a supported data source and returns its settings.
156 157 158 159 160 161 162 163 164 |
# File 'lib/google/apis/bigquerydatatransfer_v1/service.rb', line 156 def get_project_data_source(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::BigquerydatatransferV1::DataSource::Representation command.response_class = Google::Apis::BigquerydatatransferV1::DataSource command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigquerydatatransferV1::Location
Gets information about a location.
266 267 268 269 270 271 272 273 274 |
# File 'lib/google/apis/bigquerydatatransfer_v1/service.rb', line 266 def get_project_location(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::BigquerydatatransferV1::Location::Representation command.response_class = Google::Apis::BigquerydatatransferV1::Location command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_data_source(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigquerydatatransferV1::DataSource
Retrieves a supported data source and returns its settings.
431 432 433 434 435 436 437 438 439 |
# File 'lib/google/apis/bigquerydatatransfer_v1/service.rb', line 431 def get_project_location_data_source(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::BigquerydatatransferV1::DataSource::Representation command.response_class = Google::Apis::BigquerydatatransferV1::DataSource command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_transfer_config(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigquerydatatransferV1::TransferConfig
Returns information about a data transfer config.
614 615 616 617 618 619 620 621 622 |
# File 'lib/google/apis/bigquerydatatransfer_v1/service.rb', line 614 def get_project_location_transfer_config(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::BigquerydatatransferV1::TransferConfig::Representation command.response_class = Google::Apis::BigquerydatatransferV1::TransferConfig command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_transfer_config_run(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigquerydatatransferV1::TransferRun
Returns information about the particular transfer run.
891 892 893 894 895 896 897 898 899 |
# File 'lib/google/apis/bigquerydatatransfer_v1/service.rb', line 891 def get_project_location_transfer_config_run(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::BigquerydatatransferV1::TransferRun::Representation command.response_class = Google::Apis::BigquerydatatransferV1::TransferRun command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_transfer_config_transfer_resource(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigquerydatatransferV1::TransferResource
Returns a transfer resource.
1022 1023 1024 1025 1026 1027 1028 1029 1030 |
# File 'lib/google/apis/bigquerydatatransfer_v1/service.rb', line 1022 def get_project_location_transfer_config_transfer_resource(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::BigquerydatatransferV1::TransferResource::Representation command.response_class = Google::Apis::BigquerydatatransferV1::TransferResource command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_transfer_config(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigquerydatatransferV1::TransferConfig
Returns information about a data transfer config.
1219 1220 1221 1222 1223 1224 1225 1226 1227 |
# File 'lib/google/apis/bigquerydatatransfer_v1/service.rb', line 1219 def get_project_transfer_config(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::BigquerydatatransferV1::TransferConfig::Representation command.response_class = Google::Apis::BigquerydatatransferV1::TransferConfig command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_transfer_config_run(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigquerydatatransferV1::TransferRun
Returns information about the particular transfer run.
1496 1497 1498 1499 1500 1501 1502 1503 1504 |
# File 'lib/google/apis/bigquerydatatransfer_v1/service.rb', line 1496 def get_project_transfer_config_run(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::BigquerydatatransferV1::TransferRun::Representation command.response_class = Google::Apis::BigquerydatatransferV1::TransferRun command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_transfer_config_transfer_resource(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigquerydatatransferV1::TransferResource
Returns a transfer resource.
1627 1628 1629 1630 1631 1632 1633 1634 1635 |
# File 'lib/google/apis/bigquerydatatransfer_v1/service.rb', line 1627 def get_project_transfer_config_transfer_resource(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::BigquerydatatransferV1::TransferResource::Representation command.response_class = Google::Apis::BigquerydatatransferV1::TransferResource command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_data_sources(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigquerydatatransferV1::ListDataSourcesResponse
Lists supported data sources and returns their settings.
195 196 197 198 199 200 201 202 203 204 205 |
# File 'lib/google/apis/bigquerydatatransfer_v1/service.rb', line 195 def list_project_data_sources(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/dataSources', ) command.response_representation = Google::Apis::BigquerydatatransferV1::ListDataSourcesResponse::Representation command.response_class = Google::Apis::BigquerydatatransferV1::ListDataSourcesResponse command.params['parent'] = parent unless parent.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_data_sources(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigquerydatatransferV1::ListDataSourcesResponse
Lists supported data sources and returns their settings.
470 471 472 473 474 475 476 477 478 479 480 |
# File 'lib/google/apis/bigquerydatatransfer_v1/service.rb', line 470 def list_project_location_data_sources(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/dataSources', ) command.response_representation = Google::Apis::BigquerydatatransferV1::ListDataSourcesResponse::Representation command.response_class = Google::Apis::BigquerydatatransferV1::ListDataSourcesResponse command.params['parent'] = parent unless parent.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_transfer_config_run_transfer_logs(parent, message_types: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigquerydatatransferV1::ListTransferLogsResponse
Returns log messages for the transfer run.
986 987 988 989 990 991 992 993 994 995 996 997 |
# File 'lib/google/apis/bigquerydatatransfer_v1/service.rb', line 986 def list_project_location_transfer_config_run_transfer_logs(parent, message_types: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/transferLogs', ) command.response_representation = Google::Apis::BigquerydatatransferV1::ListTransferLogsResponse::Representation command.response_class = Google::Apis::BigquerydatatransferV1::ListTransferLogsResponse command.params['parent'] = parent unless parent.nil? command.query['messageTypes'] = unless .nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_transfer_config_runs(parent, page_size: nil, page_token: nil, run_attempt: nil, states: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigquerydatatransferV1::ListTransferRunsResponse
Returns information about running and completed transfer runs.
937 938 939 940 941 942 943 944 945 946 947 948 949 |
# File 'lib/google/apis/bigquerydatatransfer_v1/service.rb', line 937 def list_project_location_transfer_config_runs(parent, page_size: nil, page_token: nil, run_attempt: nil, states: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/runs', ) command.response_representation = Google::Apis::BigquerydatatransferV1::ListTransferRunsResponse::Representation command.response_class = Google::Apis::BigquerydatatransferV1::ListTransferRunsResponse command.params['parent'] = parent unless parent.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['runAttempt'] = run_attempt unless run_attempt.nil? command.query['states'] = states unless states.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_transfer_config_transfer_resources(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigquerydatatransferV1::ListTransferResourcesResponse
Returns information about transfer resources.
1074 1075 1076 1077 1078 1079 1080 1081 1082 1083 1084 1085 |
# File 'lib/google/apis/bigquerydatatransfer_v1/service.rb', line 1074 def list_project_location_transfer_config_transfer_resources(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/transferResources', ) command.response_representation = Google::Apis::BigquerydatatransferV1::ListTransferResourcesResponse::Representation command.response_class = Google::Apis::BigquerydatatransferV1::ListTransferResourcesResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_transfer_configs(parent, data_source_ids: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigquerydatatransferV1::ListTransferConfigsResponse
Returns information about all transfer configs owned by a project in the specified location.
658 659 660 661 662 663 664 665 666 667 668 669 |
# File 'lib/google/apis/bigquerydatatransfer_v1/service.rb', line 658 def list_project_location_transfer_configs(parent, data_source_ids: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/transferConfigs', ) command.response_representation = Google::Apis::BigquerydatatransferV1::ListTransferConfigsResponse::Representation command.response_class = Google::Apis::BigquerydatatransferV1::ListTransferConfigsResponse command.params['parent'] = parent unless parent.nil? command.query['dataSourceIds'] = data_source_ids unless data_source_ids.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigquerydatatransferV1::ListLocationsResponse
Lists information about the supported locations for this service. This method
lists locations based on the resource scope provided in the [
ListLocationsRequest.name] field: * Global locations: If name is empty,
the method lists the public locations available to all projects. * Project-
specific locations: If name follows the format projects/project`, the
method lists locations visible to that specific project. This includes public,
private, or other project-specific locations enabled for the project. For gRPC
and client library implementations, the resource name is passed as thename`
field. For direct service calls, the resource name is incorporated into the
request path based on the specific service implementation and version.
318 319 320 321 322 323 324 325 326 327 328 329 330 |
# File 'lib/google/apis/bigquerydatatransfer_v1/service.rb', line 318 def list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}/locations', ) command.response_representation = Google::Apis::BigquerydatatransferV1::ListLocationsResponse::Representation command.response_class = Google::Apis::BigquerydatatransferV1::ListLocationsResponse command.params['name'] = name unless name.nil? command.query['extraLocationTypes'] = extra_location_types unless extra_location_types.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_transfer_config_run_transfer_logs(parent, message_types: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigquerydatatransferV1::ListTransferLogsResponse
Returns log messages for the transfer run.
1591 1592 1593 1594 1595 1596 1597 1598 1599 1600 1601 1602 |
# File 'lib/google/apis/bigquerydatatransfer_v1/service.rb', line 1591 def list_project_transfer_config_run_transfer_logs(parent, message_types: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/transferLogs', ) command.response_representation = Google::Apis::BigquerydatatransferV1::ListTransferLogsResponse::Representation command.response_class = Google::Apis::BigquerydatatransferV1::ListTransferLogsResponse command.params['parent'] = parent unless parent.nil? command.query['messageTypes'] = unless .nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_transfer_config_runs(parent, page_size: nil, page_token: nil, run_attempt: nil, states: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigquerydatatransferV1::ListTransferRunsResponse
Returns information about running and completed transfer runs.
1542 1543 1544 1545 1546 1547 1548 1549 1550 1551 1552 1553 1554 |
# File 'lib/google/apis/bigquerydatatransfer_v1/service.rb', line 1542 def list_project_transfer_config_runs(parent, page_size: nil, page_token: nil, run_attempt: nil, states: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/runs', ) command.response_representation = Google::Apis::BigquerydatatransferV1::ListTransferRunsResponse::Representation command.response_class = Google::Apis::BigquerydatatransferV1::ListTransferRunsResponse command.params['parent'] = parent unless parent.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['runAttempt'] = run_attempt unless run_attempt.nil? command.query['states'] = states unless states.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_transfer_config_transfer_resources(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigquerydatatransferV1::ListTransferResourcesResponse
Returns information about transfer resources.
1679 1680 1681 1682 1683 1684 1685 1686 1687 1688 1689 1690 |
# File 'lib/google/apis/bigquerydatatransfer_v1/service.rb', line 1679 def list_project_transfer_config_transfer_resources(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/transferResources', ) command.response_representation = Google::Apis::BigquerydatatransferV1::ListTransferResourcesResponse::Representation command.response_class = Google::Apis::BigquerydatatransferV1::ListTransferResourcesResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_transfer_configs(parent, data_source_ids: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigquerydatatransferV1::ListTransferConfigsResponse
Returns information about all transfer configs owned by a project in the specified location.
1263 1264 1265 1266 1267 1268 1269 1270 1271 1272 1273 1274 |
# File 'lib/google/apis/bigquerydatatransfer_v1/service.rb', line 1263 def list_project_transfer_configs(parent, data_source_ids: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/transferConfigs', ) command.response_representation = Google::Apis::BigquerydatatransferV1::ListTransferConfigsResponse::Representation command.response_class = Google::Apis::BigquerydatatransferV1::ListTransferConfigsResponse command.params['parent'] = parent unless parent.nil? command.query['dataSourceIds'] = data_source_ids unless data_source_ids.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_project_location_transfer_config(name, transfer_config_object = nil, authorization_code: nil, service_account_name: nil, update_mask: nil, version_info: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigquerydatatransferV1::TransferConfig
Updates a data transfer configuration. All fields must be set, even if they are not updated.
733 734 735 736 737 738 739 740 741 742 743 744 745 746 747 |
# File 'lib/google/apis/bigquerydatatransfer_v1/service.rb', line 733 def patch_project_location_transfer_config(name, transfer_config_object = nil, authorization_code: nil, service_account_name: nil, update_mask: nil, version_info: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1/{+name}', ) command.request_representation = Google::Apis::BigquerydatatransferV1::TransferConfig::Representation command.request_object = transfer_config_object command.response_representation = Google::Apis::BigquerydatatransferV1::TransferConfig::Representation command.response_class = Google::Apis::BigquerydatatransferV1::TransferConfig command.params['name'] = name unless name.nil? command.query['authorizationCode'] = unless .nil? command.query['serviceAccountName'] = service_account_name unless service_account_name.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['versionInfo'] = version_info unless version_info.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_project_transfer_config(name, transfer_config_object = nil, authorization_code: nil, service_account_name: nil, update_mask: nil, version_info: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigquerydatatransferV1::TransferConfig
Updates a data transfer configuration. All fields must be set, even if they are not updated.
1338 1339 1340 1341 1342 1343 1344 1345 1346 1347 1348 1349 1350 1351 1352 |
# File 'lib/google/apis/bigquerydatatransfer_v1/service.rb', line 1338 def patch_project_transfer_config(name, transfer_config_object = nil, authorization_code: nil, service_account_name: nil, update_mask: nil, version_info: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1/{+name}', ) command.request_representation = Google::Apis::BigquerydatatransferV1::TransferConfig::Representation command.request_object = transfer_config_object command.response_representation = Google::Apis::BigquerydatatransferV1::TransferConfig::Representation command.response_class = Google::Apis::BigquerydatatransferV1::TransferConfig command.params['name'] = name unless name.nil? command.query['authorizationCode'] = unless .nil? command.query['serviceAccountName'] = service_account_name unless service_account_name.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['versionInfo'] = version_info unless version_info.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#schedule_project_location_transfer_config_runs(parent, schedule_transfer_runs_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigquerydatatransferV1::ScheduleTransferRunsResponse
Creates transfer runs for a time range [start_time, end_time]. For each date - or whatever granularity the data source supports - in the range, one transfer run is created. Note that runs are created per UTC time in the time range. DEPRECATED: use StartManualTransferRuns instead.
777 778 779 780 781 782 783 784 785 786 787 |
# File 'lib/google/apis/bigquerydatatransfer_v1/service.rb', line 777 def schedule_project_location_transfer_config_runs(parent, schedule_transfer_runs_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+parent}:scheduleRuns', ) command.request_representation = Google::Apis::BigquerydatatransferV1::ScheduleTransferRunsRequest::Representation command.request_object = schedule_transfer_runs_request_object command.response_representation = Google::Apis::BigquerydatatransferV1::ScheduleTransferRunsResponse::Representation command.response_class = Google::Apis::BigquerydatatransferV1::ScheduleTransferRunsResponse command.params['parent'] = parent unless parent.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#schedule_project_transfer_config_runs(parent, schedule_transfer_runs_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigquerydatatransferV1::ScheduleTransferRunsResponse
Creates transfer runs for a time range [start_time, end_time]. For each date - or whatever granularity the data source supports - in the range, one transfer run is created. Note that runs are created per UTC time in the time range. DEPRECATED: use StartManualTransferRuns instead.
1382 1383 1384 1385 1386 1387 1388 1389 1390 1391 1392 |
# File 'lib/google/apis/bigquerydatatransfer_v1/service.rb', line 1382 def schedule_project_transfer_config_runs(parent, schedule_transfer_runs_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+parent}:scheduleRuns', ) command.request_representation = Google::Apis::BigquerydatatransferV1::ScheduleTransferRunsRequest::Representation command.request_object = schedule_transfer_runs_request_object command.response_representation = Google::Apis::BigquerydatatransferV1::ScheduleTransferRunsResponse::Representation command.response_class = Google::Apis::BigquerydatatransferV1::ScheduleTransferRunsResponse command.params['parent'] = parent unless parent.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#start_project_location_transfer_config_manual_runs(parent, start_manual_transfer_runs_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigquerydatatransferV1::StartManualTransferRunsResponse
Manually initiates transfer runs. You can schedule these runs in two ways: 1. For a specific point in time using the 'requested_run_time' parameter. 2. For a period between 'start_time' (inclusive) and 'end_time' (exclusive). If scheduling a single run, it is set to execute immediately (schedule_time equals the current time). When scheduling multiple runs within a time range, the first run starts now, and subsequent runs are delayed by 15 seconds each.
819 820 821 822 823 824 825 826 827 828 829 |
# File 'lib/google/apis/bigquerydatatransfer_v1/service.rb', line 819 def start_project_location_transfer_config_manual_runs(parent, start_manual_transfer_runs_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+parent}:startManualRuns', ) command.request_representation = Google::Apis::BigquerydatatransferV1::StartManualTransferRunsRequest::Representation command.request_object = start_manual_transfer_runs_request_object command.response_representation = Google::Apis::BigquerydatatransferV1::StartManualTransferRunsResponse::Representation command.response_class = Google::Apis::BigquerydatatransferV1::StartManualTransferRunsResponse command.params['parent'] = parent unless parent.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#start_project_transfer_config_manual_runs(parent, start_manual_transfer_runs_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigquerydatatransferV1::StartManualTransferRunsResponse
Manually initiates transfer runs. You can schedule these runs in two ways: 1. For a specific point in time using the 'requested_run_time' parameter. 2. For a period between 'start_time' (inclusive) and 'end_time' (exclusive). If scheduling a single run, it is set to execute immediately (schedule_time equals the current time). When scheduling multiple runs within a time range, the first run starts now, and subsequent runs are delayed by 15 seconds each.
1424 1425 1426 1427 1428 1429 1430 1431 1432 1433 1434 |
# File 'lib/google/apis/bigquerydatatransfer_v1/service.rb', line 1424 def start_project_transfer_config_manual_runs(parent, start_manual_transfer_runs_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+parent}:startManualRuns', ) command.request_representation = Google::Apis::BigquerydatatransferV1::StartManualTransferRunsRequest::Representation command.request_object = start_manual_transfer_runs_request_object command.response_representation = Google::Apis::BigquerydatatransferV1::StartManualTransferRunsResponse::Representation command.response_class = Google::Apis::BigquerydatatransferV1::StartManualTransferRunsResponse command.params['parent'] = parent unless parent.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#unenroll_location_data_sources(name, unenroll_data_sources_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigquerydatatransferV1::Empty
Unenroll data sources in a user project. This allows users to remove transfer configurations for these data sources. They will no longer appear in the ListDataSources RPC and will also no longer appear in the BigQuery UI. Data transfers configurations of unenrolled data sources will not be scheduled.
357 358 359 360 361 362 363 364 365 366 367 |
# File 'lib/google/apis/bigquerydatatransfer_v1/service.rb', line 357 def unenroll_location_data_sources(name, unenroll_data_sources_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+name}:unenrollDataSources', ) command.request_representation = Google::Apis::BigquerydatatransferV1::UnenrollDataSourcesRequest::Representation command.request_object = unenroll_data_sources_request_object command.response_representation = Google::Apis::BigquerydatatransferV1::Empty::Representation command.response_class = Google::Apis::BigquerydatatransferV1::Empty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |