Class: Google::Apis::BigquerydatatransferV1::TransferResourceStatusDetail

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigquerydatatransfer_v1/classes.rb,
lib/google/apis/bigquerydatatransfer_v1/representations.rb,
lib/google/apis/bigquerydatatransfer_v1/representations.rb

Overview

Status details of the resource being transferred.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TransferResourceStatusDetail

Returns a new instance of TransferResourceStatusDetail.



1325
1326
1327
# File 'lib/google/apis/bigquerydatatransfer_v1/classes.rb', line 1325

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#completed_percentageFloat

Output only. Percentage of the transfer completed. Valid values: 0-100. Corresponds to the JSON property completedPercentage

Returns:

  • (Float)


1303
1304
1305
# File 'lib/google/apis/bigquerydatatransfer_v1/classes.rb', line 1303

def completed_percentage
  @completed_percentage
end

#errorGoogle::Apis::BigquerydatatransferV1::Status

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property error



1313
1314
1315
# File 'lib/google/apis/bigquerydatatransfer_v1/classes.rb', line 1313

def error
  @error
end

#stateString

Optional. Transfer state of the resource. Corresponds to the JSON property state

Returns:

  • (String)


1318
1319
1320
# File 'lib/google/apis/bigquerydatatransfer_v1/classes.rb', line 1318

def state
  @state
end

#summaryGoogle::Apis::BigquerydatatransferV1::TransferStatusSummary

Status summary of the resource being transferred. Corresponds to the JSON property summary



1323
1324
1325
# File 'lib/google/apis/bigquerydatatransfer_v1/classes.rb', line 1323

def summary
  @summary
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1330
1331
1332
1333
1334
1335
# File 'lib/google/apis/bigquerydatatransfer_v1/classes.rb', line 1330

def update!(**args)
  @completed_percentage = args[:completed_percentage] if args.key?(:completed_percentage)
  @error = args[:error] if args.key?(:error)
  @state = args[:state] if args.key?(:state)
  @summary = args[:summary] if args.key?(:summary)
end