Class: Google::Apis::BigquerydatatransferV1::BigQueryDataTransferService
- Inherits:
-
Core::BaseService
- Object
- Core::BaseService
- Google::Apis::BigquerydatatransferV1::BigQueryDataTransferService
- Defined in:
- lib/google/apis/bigquerydatatransfer_v1/service.rb
Overview
BigQuery Data Transfer API
Schedule queries or transfer external data from SaaS applications to Google BigQuery on a regular basis.
Constant Summary collapse
- DEFAULT_ENDPOINT_TEMPLATE =
"https://bigquerydatatransfer.$UNIVERSE_DOMAIN$/"
Instance Attribute Summary collapse
-
#key ⇒ String
API key.
-
#quota_user ⇒ String
Available to use for quota purposes for server-side applications.
Instance Method Summary collapse
-
#check_project_data_source_valid_creds(name, check_valid_creds_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigquerydatatransferV1::CheckValidCredsResponse
Returns true if valid credentials exist for the given data source and requesting user.
-
#check_project_location_data_source_valid_creds(name, check_valid_creds_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigquerydatatransferV1::CheckValidCredsResponse
Returns true if valid credentials exist for the given data source and requesting user.
-
#create_project_location_transfer_config(parent, transfer_config_object = nil, authorization_code: nil, service_account_name: nil, version_info: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigquerydatatransferV1::TransferConfig
Creates a new data transfer configuration.
-
#create_project_transfer_config(parent, transfer_config_object = nil, authorization_code: nil, service_account_name: nil, version_info: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigquerydatatransferV1::TransferConfig
Creates a new data transfer configuration.
-
#delete_project_location_transfer_config(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigquerydatatransferV1::Empty
Deletes a data transfer configuration, including any associated transfer runs and logs.
-
#delete_project_location_transfer_config_run(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigquerydatatransferV1::Empty
Deletes the specified transfer run.
-
#delete_project_transfer_config(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigquerydatatransferV1::Empty
Deletes a data transfer configuration, including any associated transfer runs and logs.
-
#delete_project_transfer_config_run(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigquerydatatransferV1::Empty
Deletes the specified transfer run.
-
#enroll_location_data_sources(name, enroll_data_sources_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigquerydatatransferV1::Empty
Enroll data sources in a user project.
-
#enroll_project_data_sources(name, enroll_data_sources_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigquerydatatransferV1::Empty
Enroll data sources in a user project.
-
#get_project_data_source(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigquerydatatransferV1::DataSource
Retrieves a supported data source and returns its settings.
-
#get_project_location(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigquerydatatransferV1::Location
Gets information about a location.
-
#get_project_location_data_source(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigquerydatatransferV1::DataSource
Retrieves a supported data source and returns its settings.
-
#get_project_location_transfer_config(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigquerydatatransferV1::TransferConfig
Returns information about a data transfer config.
-
#get_project_location_transfer_config_run(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigquerydatatransferV1::TransferRun
Returns information about the particular transfer run.
-
#get_project_transfer_config(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigquerydatatransferV1::TransferConfig
Returns information about a data transfer config.
-
#get_project_transfer_config_run(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigquerydatatransferV1::TransferRun
Returns information about the particular transfer run.
-
#initialize ⇒ BigQueryDataTransferService
constructor
A new instance of BigQueryDataTransferService.
-
#list_project_data_sources(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigquerydatatransferV1::ListDataSourcesResponse
Lists supported data sources and returns their settings.
-
#list_project_location_data_sources(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigquerydatatransferV1::ListDataSourcesResponse
Lists supported data sources and returns their settings.
-
#list_project_location_transfer_config_run_transfer_logs(parent, message_types: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigquerydatatransferV1::ListTransferLogsResponse
Returns log messages for the transfer run.
-
#list_project_location_transfer_config_runs(parent, page_size: nil, page_token: nil, run_attempt: nil, states: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigquerydatatransferV1::ListTransferRunsResponse
Returns information about running and completed transfer runs.
-
#list_project_location_transfer_configs(parent, data_source_ids: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigquerydatatransferV1::ListTransferConfigsResponse
Returns information about all transfer configs owned by a project in the specified location.
-
#list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigquerydatatransferV1::ListLocationsResponse
Lists information about the supported locations for this service.
-
#list_project_transfer_config_run_transfer_logs(parent, message_types: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigquerydatatransferV1::ListTransferLogsResponse
Returns log messages for the transfer run.
-
#list_project_transfer_config_runs(parent, page_size: nil, page_token: nil, run_attempt: nil, states: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigquerydatatransferV1::ListTransferRunsResponse
Returns information about running and completed transfer runs.
-
#list_project_transfer_configs(parent, data_source_ids: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigquerydatatransferV1::ListTransferConfigsResponse
Returns information about all transfer configs owned by a project in the specified location.
-
#patch_project_location_transfer_config(name, transfer_config_object = nil, authorization_code: nil, service_account_name: nil, update_mask: nil, version_info: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigquerydatatransferV1::TransferConfig
Updates a data transfer configuration.
-
#patch_project_transfer_config(name, transfer_config_object = nil, authorization_code: nil, service_account_name: nil, update_mask: nil, version_info: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigquerydatatransferV1::TransferConfig
Updates a data transfer configuration.
-
#schedule_project_location_transfer_config_runs(parent, schedule_transfer_runs_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigquerydatatransferV1::ScheduleTransferRunsResponse
Creates transfer runs for a time range [start_time, end_time].
-
#schedule_project_transfer_config_runs(parent, schedule_transfer_runs_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigquerydatatransferV1::ScheduleTransferRunsResponse
Creates transfer runs for a time range [start_time, end_time].
-
#start_project_location_transfer_config_manual_runs(parent, start_manual_transfer_runs_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigquerydatatransferV1::StartManualTransferRunsResponse
Manually initiates transfer runs.
-
#start_project_transfer_config_manual_runs(parent, start_manual_transfer_runs_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigquerydatatransferV1::StartManualTransferRunsResponse
Manually initiates transfer runs.
-
#unenroll_location_data_sources(name, unenroll_data_sources_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigquerydatatransferV1::Empty
Unenroll data sources in a user project.
Constructor Details
#initialize ⇒ BigQueryDataTransferService
Returns a new instance of BigQueryDataTransferService.
48 49 50 51 52 53 |
# File 'lib/google/apis/bigquerydatatransfer_v1/service.rb', line 48 def initialize super(DEFAULT_ENDPOINT_TEMPLATE, '', client_name: 'google-apis-bigquerydatatransfer_v1', client_version: Google::Apis::BigquerydatatransferV1::GEM_VERSION) @batch_path = 'batch' end |
Instance Attribute Details
#key ⇒ String
Returns API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
41 42 43 |
# File 'lib/google/apis/bigquerydatatransfer_v1/service.rb', line 41 def key @key end |
#quota_user ⇒ String
Returns Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
46 47 48 |
# File 'lib/google/apis/bigquerydatatransfer_v1/service.rb', line 46 def quota_user @quota_user end |
Instance Method Details
#check_project_data_source_valid_creds(name, check_valid_creds_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigquerydatatransferV1::CheckValidCredsResponse
Returns true if valid credentials exist for the given data source and requesting user.
120 121 122 123 124 125 126 127 128 129 130 |
# File 'lib/google/apis/bigquerydatatransfer_v1/service.rb', line 120 def check_project_data_source_valid_creds(name, check_valid_creds_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+name}:checkValidCreds', ) command.request_representation = Google::Apis::BigquerydatatransferV1::CheckValidCredsRequest::Representation command.request_object = check_valid_creds_request_object command.response_representation = Google::Apis::BigquerydatatransferV1::CheckValidCredsResponse::Representation command.response_class = Google::Apis::BigquerydatatransferV1::CheckValidCredsResponse command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#check_project_location_data_source_valid_creds(name, check_valid_creds_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigquerydatatransferV1::CheckValidCredsResponse
Returns true if valid credentials exist for the given data source and requesting user.
390 391 392 393 394 395 396 397 398 399 400 |
# File 'lib/google/apis/bigquerydatatransfer_v1/service.rb', line 390 def check_project_location_data_source_valid_creds(name, check_valid_creds_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+name}:checkValidCreds', ) command.request_representation = Google::Apis::BigquerydatatransferV1::CheckValidCredsRequest::Representation command.request_object = check_valid_creds_request_object command.response_representation = Google::Apis::BigquerydatatransferV1::CheckValidCredsResponse::Representation command.response_class = Google::Apis::BigquerydatatransferV1::CheckValidCredsResponse command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_project_location_transfer_config(parent, transfer_config_object = nil, authorization_code: nil, service_account_name: nil, version_info: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigquerydatatransferV1::TransferConfig
Creates a new data transfer configuration.
535 536 537 538 539 540 541 542 543 544 545 546 547 548 |
# File 'lib/google/apis/bigquerydatatransfer_v1/service.rb', line 535 def create_project_location_transfer_config(parent, transfer_config_object = nil, authorization_code: nil, service_account_name: nil, version_info: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+parent}/transferConfigs', ) command.request_representation = Google::Apis::BigquerydatatransferV1::TransferConfig::Representation command.request_object = transfer_config_object command.response_representation = Google::Apis::BigquerydatatransferV1::TransferConfig::Representation command.response_class = Google::Apis::BigquerydatatransferV1::TransferConfig command.params['parent'] = parent unless parent.nil? command.query['authorizationCode'] = unless .nil? command.query['serviceAccountName'] = service_account_name unless service_account_name.nil? command.query['versionInfo'] = version_info unless version_info.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_project_transfer_config(parent, transfer_config_object = nil, authorization_code: nil, service_account_name: nil, version_info: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigquerydatatransferV1::TransferConfig
Creates a new data transfer configuration.
1052 1053 1054 1055 1056 1057 1058 1059 1060 1061 1062 1063 1064 1065 |
# File 'lib/google/apis/bigquerydatatransfer_v1/service.rb', line 1052 def create_project_transfer_config(parent, transfer_config_object = nil, authorization_code: nil, service_account_name: nil, version_info: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+parent}/transferConfigs', ) command.request_representation = Google::Apis::BigquerydatatransferV1::TransferConfig::Representation command.request_object = transfer_config_object command.response_representation = Google::Apis::BigquerydatatransferV1::TransferConfig::Representation command.response_class = Google::Apis::BigquerydatatransferV1::TransferConfig command.params['parent'] = parent unless parent.nil? command.query['authorizationCode'] = unless .nil? command.query['serviceAccountName'] = service_account_name unless service_account_name.nil? command.query['versionInfo'] = version_info unless version_info.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_transfer_config(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigquerydatatransferV1::Empty
Deletes a data transfer configuration, including any associated transfer runs and logs.
575 576 577 578 579 580 581 582 583 |
# File 'lib/google/apis/bigquerydatatransfer_v1/service.rb', line 575 def delete_project_location_transfer_config(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1/{+name}', ) command.response_representation = Google::Apis::BigquerydatatransferV1::Empty::Representation command.response_class = Google::Apis::BigquerydatatransferV1::Empty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_transfer_config_run(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigquerydatatransferV1::Empty
Deletes the specified transfer run.
851 852 853 854 855 856 857 858 859 |
# File 'lib/google/apis/bigquerydatatransfer_v1/service.rb', line 851 def delete_project_location_transfer_config_run(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1/{+name}', ) command.response_representation = Google::Apis::BigquerydatatransferV1::Empty::Representation command.response_class = Google::Apis::BigquerydatatransferV1::Empty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_transfer_config(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigquerydatatransferV1::Empty
Deletes a data transfer configuration, including any associated transfer runs and logs.
1092 1093 1094 1095 1096 1097 1098 1099 1100 |
# File 'lib/google/apis/bigquerydatatransfer_v1/service.rb', line 1092 def delete_project_transfer_config(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1/{+name}', ) command.response_representation = Google::Apis::BigquerydatatransferV1::Empty::Representation command.response_class = Google::Apis::BigquerydatatransferV1::Empty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_transfer_config_run(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigquerydatatransferV1::Empty
Deletes the specified transfer run.
1368 1369 1370 1371 1372 1373 1374 1375 1376 |
# File 'lib/google/apis/bigquerydatatransfer_v1/service.rb', line 1368 def delete_project_transfer_config_run(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1/{+name}', ) command.response_representation = Google::Apis::BigquerydatatransferV1::Empty::Representation command.response_class = Google::Apis::BigquerydatatransferV1::Empty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#enroll_location_data_sources(name, enroll_data_sources_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigquerydatatransferV1::Empty
Enroll data sources in a user project. This allows users to create transfer configurations for these data sources. They will also appear in the ListDataSources RPC and as such, will appear in the BigQuery UI, and the documents can be found in the public guide for BigQuery Web UI and Data Transfer Service.
234 235 236 237 238 239 240 241 242 243 244 |
# File 'lib/google/apis/bigquerydatatransfer_v1/service.rb', line 234 def enroll_location_data_sources(name, enroll_data_sources_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+name}:enrollDataSources', ) command.request_representation = Google::Apis::BigquerydatatransferV1::EnrollDataSourcesRequest::Representation command.request_object = enroll_data_sources_request_object command.response_representation = Google::Apis::BigquerydatatransferV1::Empty::Representation command.response_class = Google::Apis::BigquerydatatransferV1::Empty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#enroll_project_data_sources(name, enroll_data_sources_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigquerydatatransferV1::Empty
Enroll data sources in a user project. This allows users to create transfer configurations for these data sources. They will also appear in the ListDataSources RPC and as such, will appear in the BigQuery UI, and the documents can be found in the public guide for BigQuery Web UI and Data Transfer Service.
82 83 84 85 86 87 88 89 90 91 92 |
# File 'lib/google/apis/bigquerydatatransfer_v1/service.rb', line 82 def enroll_project_data_sources(name, enroll_data_sources_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+name}:enrollDataSources', ) command.request_representation = Google::Apis::BigquerydatatransferV1::EnrollDataSourcesRequest::Representation command.request_object = enroll_data_sources_request_object command.response_representation = Google::Apis::BigquerydatatransferV1::Empty::Representation command.response_class = Google::Apis::BigquerydatatransferV1::Empty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_data_source(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigquerydatatransferV1::DataSource
Retrieves a supported data source and returns its settings.
156 157 158 159 160 161 162 163 164 |
# File 'lib/google/apis/bigquerydatatransfer_v1/service.rb', line 156 def get_project_data_source(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::BigquerydatatransferV1::DataSource::Representation command.response_class = Google::Apis::BigquerydatatransferV1::DataSource command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigquerydatatransferV1::Location
Gets information about a location.
266 267 268 269 270 271 272 273 274 |
# File 'lib/google/apis/bigquerydatatransfer_v1/service.rb', line 266 def get_project_location(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::BigquerydatatransferV1::Location::Representation command.response_class = Google::Apis::BigquerydatatransferV1::Location command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_data_source(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigquerydatatransferV1::DataSource
Retrieves a supported data source and returns its settings.
426 427 428 429 430 431 432 433 434 |
# File 'lib/google/apis/bigquerydatatransfer_v1/service.rb', line 426 def get_project_location_data_source(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::BigquerydatatransferV1::DataSource::Representation command.response_class = Google::Apis::BigquerydatatransferV1::DataSource command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_transfer_config(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigquerydatatransferV1::TransferConfig
Returns information about a data transfer config.
609 610 611 612 613 614 615 616 617 |
# File 'lib/google/apis/bigquerydatatransfer_v1/service.rb', line 609 def get_project_location_transfer_config(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::BigquerydatatransferV1::TransferConfig::Representation command.response_class = Google::Apis::BigquerydatatransferV1::TransferConfig command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_transfer_config_run(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigquerydatatransferV1::TransferRun
Returns information about the particular transfer run.
886 887 888 889 890 891 892 893 894 |
# File 'lib/google/apis/bigquerydatatransfer_v1/service.rb', line 886 def get_project_location_transfer_config_run(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::BigquerydatatransferV1::TransferRun::Representation command.response_class = Google::Apis::BigquerydatatransferV1::TransferRun command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_transfer_config(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigquerydatatransferV1::TransferConfig
Returns information about a data transfer config.
1126 1127 1128 1129 1130 1131 1132 1133 1134 |
# File 'lib/google/apis/bigquerydatatransfer_v1/service.rb', line 1126 def get_project_transfer_config(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::BigquerydatatransferV1::TransferConfig::Representation command.response_class = Google::Apis::BigquerydatatransferV1::TransferConfig command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_transfer_config_run(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigquerydatatransferV1::TransferRun
Returns information about the particular transfer run.
1403 1404 1405 1406 1407 1408 1409 1410 1411 |
# File 'lib/google/apis/bigquerydatatransfer_v1/service.rb', line 1403 def get_project_transfer_config_run(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::BigquerydatatransferV1::TransferRun::Representation command.response_class = Google::Apis::BigquerydatatransferV1::TransferRun command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_data_sources(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigquerydatatransferV1::ListDataSourcesResponse
Lists supported data sources and returns their settings.
195 196 197 198 199 200 201 202 203 204 205 |
# File 'lib/google/apis/bigquerydatatransfer_v1/service.rb', line 195 def list_project_data_sources(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/dataSources', ) command.response_representation = Google::Apis::BigquerydatatransferV1::ListDataSourcesResponse::Representation command.response_class = Google::Apis::BigquerydatatransferV1::ListDataSourcesResponse command.params['parent'] = parent unless parent.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_data_sources(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigquerydatatransferV1::ListDataSourcesResponse
Lists supported data sources and returns their settings.
465 466 467 468 469 470 471 472 473 474 475 |
# File 'lib/google/apis/bigquerydatatransfer_v1/service.rb', line 465 def list_project_location_data_sources(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/dataSources', ) command.response_representation = Google::Apis::BigquerydatatransferV1::ListDataSourcesResponse::Representation command.response_class = Google::Apis::BigquerydatatransferV1::ListDataSourcesResponse command.params['parent'] = parent unless parent.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_transfer_config_run_transfer_logs(parent, message_types: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigquerydatatransferV1::ListTransferLogsResponse
Returns log messages for the transfer run.
981 982 983 984 985 986 987 988 989 990 991 992 |
# File 'lib/google/apis/bigquerydatatransfer_v1/service.rb', line 981 def list_project_location_transfer_config_run_transfer_logs(parent, message_types: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/transferLogs', ) command.response_representation = Google::Apis::BigquerydatatransferV1::ListTransferLogsResponse::Representation command.response_class = Google::Apis::BigquerydatatransferV1::ListTransferLogsResponse command.params['parent'] = parent unless parent.nil? command.query['messageTypes'] = unless .nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_transfer_config_runs(parent, page_size: nil, page_token: nil, run_attempt: nil, states: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigquerydatatransferV1::ListTransferRunsResponse
Returns information about running and completed transfer runs.
932 933 934 935 936 937 938 939 940 941 942 943 944 |
# File 'lib/google/apis/bigquerydatatransfer_v1/service.rb', line 932 def list_project_location_transfer_config_runs(parent, page_size: nil, page_token: nil, run_attempt: nil, states: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/runs', ) command.response_representation = Google::Apis::BigquerydatatransferV1::ListTransferRunsResponse::Representation command.response_class = Google::Apis::BigquerydatatransferV1::ListTransferRunsResponse command.params['parent'] = parent unless parent.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['runAttempt'] = run_attempt unless run_attempt.nil? command.query['states'] = states unless states.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_transfer_configs(parent, data_source_ids: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigquerydatatransferV1::ListTransferConfigsResponse
Returns information about all transfer configs owned by a project in the specified location.
653 654 655 656 657 658 659 660 661 662 663 664 |
# File 'lib/google/apis/bigquerydatatransfer_v1/service.rb', line 653 def list_project_location_transfer_configs(parent, data_source_ids: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/transferConfigs', ) command.response_representation = Google::Apis::BigquerydatatransferV1::ListTransferConfigsResponse::Representation command.response_class = Google::Apis::BigquerydatatransferV1::ListTransferConfigsResponse command.params['parent'] = parent unless parent.nil? command.query['dataSourceIds'] = data_source_ids unless data_source_ids.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigquerydatatransferV1::ListLocationsResponse
Lists information about the supported locations for this service. This method
can be called in two ways: * List all public locations: Use the path GET /
v1/locations. * List project-visible locations: Use the path GET /v1/
projects/project_id/locations. This may include public locations as well as
private or other locations specifically visible to the project.
313 314 315 316 317 318 319 320 321 322 323 324 325 |
# File 'lib/google/apis/bigquerydatatransfer_v1/service.rb', line 313 def list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}/locations', ) command.response_representation = Google::Apis::BigquerydatatransferV1::ListLocationsResponse::Representation command.response_class = Google::Apis::BigquerydatatransferV1::ListLocationsResponse command.params['name'] = name unless name.nil? command.query['extraLocationTypes'] = extra_location_types unless extra_location_types.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_transfer_config_run_transfer_logs(parent, message_types: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigquerydatatransferV1::ListTransferLogsResponse
Returns log messages for the transfer run.
1498 1499 1500 1501 1502 1503 1504 1505 1506 1507 1508 1509 |
# File 'lib/google/apis/bigquerydatatransfer_v1/service.rb', line 1498 def list_project_transfer_config_run_transfer_logs(parent, message_types: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/transferLogs', ) command.response_representation = Google::Apis::BigquerydatatransferV1::ListTransferLogsResponse::Representation command.response_class = Google::Apis::BigquerydatatransferV1::ListTransferLogsResponse command.params['parent'] = parent unless parent.nil? command.query['messageTypes'] = unless .nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_transfer_config_runs(parent, page_size: nil, page_token: nil, run_attempt: nil, states: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigquerydatatransferV1::ListTransferRunsResponse
Returns information about running and completed transfer runs.
1449 1450 1451 1452 1453 1454 1455 1456 1457 1458 1459 1460 1461 |
# File 'lib/google/apis/bigquerydatatransfer_v1/service.rb', line 1449 def list_project_transfer_config_runs(parent, page_size: nil, page_token: nil, run_attempt: nil, states: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/runs', ) command.response_representation = Google::Apis::BigquerydatatransferV1::ListTransferRunsResponse::Representation command.response_class = Google::Apis::BigquerydatatransferV1::ListTransferRunsResponse command.params['parent'] = parent unless parent.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['runAttempt'] = run_attempt unless run_attempt.nil? command.query['states'] = states unless states.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_transfer_configs(parent, data_source_ids: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigquerydatatransferV1::ListTransferConfigsResponse
Returns information about all transfer configs owned by a project in the specified location.
1170 1171 1172 1173 1174 1175 1176 1177 1178 1179 1180 1181 |
# File 'lib/google/apis/bigquerydatatransfer_v1/service.rb', line 1170 def list_project_transfer_configs(parent, data_source_ids: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/transferConfigs', ) command.response_representation = Google::Apis::BigquerydatatransferV1::ListTransferConfigsResponse::Representation command.response_class = Google::Apis::BigquerydatatransferV1::ListTransferConfigsResponse command.params['parent'] = parent unless parent.nil? command.query['dataSourceIds'] = data_source_ids unless data_source_ids.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_project_location_transfer_config(name, transfer_config_object = nil, authorization_code: nil, service_account_name: nil, update_mask: nil, version_info: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigquerydatatransferV1::TransferConfig
Updates a data transfer configuration. All fields must be set, even if they are not updated.
728 729 730 731 732 733 734 735 736 737 738 739 740 741 742 |
# File 'lib/google/apis/bigquerydatatransfer_v1/service.rb', line 728 def patch_project_location_transfer_config(name, transfer_config_object = nil, authorization_code: nil, service_account_name: nil, update_mask: nil, version_info: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1/{+name}', ) command.request_representation = Google::Apis::BigquerydatatransferV1::TransferConfig::Representation command.request_object = transfer_config_object command.response_representation = Google::Apis::BigquerydatatransferV1::TransferConfig::Representation command.response_class = Google::Apis::BigquerydatatransferV1::TransferConfig command.params['name'] = name unless name.nil? command.query['authorizationCode'] = unless .nil? command.query['serviceAccountName'] = service_account_name unless service_account_name.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['versionInfo'] = version_info unless version_info.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_project_transfer_config(name, transfer_config_object = nil, authorization_code: nil, service_account_name: nil, update_mask: nil, version_info: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigquerydatatransferV1::TransferConfig
Updates a data transfer configuration. All fields must be set, even if they are not updated.
1245 1246 1247 1248 1249 1250 1251 1252 1253 1254 1255 1256 1257 1258 1259 |
# File 'lib/google/apis/bigquerydatatransfer_v1/service.rb', line 1245 def patch_project_transfer_config(name, transfer_config_object = nil, authorization_code: nil, service_account_name: nil, update_mask: nil, version_info: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1/{+name}', ) command.request_representation = Google::Apis::BigquerydatatransferV1::TransferConfig::Representation command.request_object = transfer_config_object command.response_representation = Google::Apis::BigquerydatatransferV1::TransferConfig::Representation command.response_class = Google::Apis::BigquerydatatransferV1::TransferConfig command.params['name'] = name unless name.nil? command.query['authorizationCode'] = unless .nil? command.query['serviceAccountName'] = service_account_name unless service_account_name.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['versionInfo'] = version_info unless version_info.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#schedule_project_location_transfer_config_runs(parent, schedule_transfer_runs_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigquerydatatransferV1::ScheduleTransferRunsResponse
Creates transfer runs for a time range [start_time, end_time]. For each date - or whatever granularity the data source supports - in the range, one transfer run is created. Note that runs are created per UTC time in the time range. DEPRECATED: use StartManualTransferRuns instead.
772 773 774 775 776 777 778 779 780 781 782 |
# File 'lib/google/apis/bigquerydatatransfer_v1/service.rb', line 772 def schedule_project_location_transfer_config_runs(parent, schedule_transfer_runs_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+parent}:scheduleRuns', ) command.request_representation = Google::Apis::BigquerydatatransferV1::ScheduleTransferRunsRequest::Representation command.request_object = schedule_transfer_runs_request_object command.response_representation = Google::Apis::BigquerydatatransferV1::ScheduleTransferRunsResponse::Representation command.response_class = Google::Apis::BigquerydatatransferV1::ScheduleTransferRunsResponse command.params['parent'] = parent unless parent.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#schedule_project_transfer_config_runs(parent, schedule_transfer_runs_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigquerydatatransferV1::ScheduleTransferRunsResponse
Creates transfer runs for a time range [start_time, end_time]. For each date - or whatever granularity the data source supports - in the range, one transfer run is created. Note that runs are created per UTC time in the time range. DEPRECATED: use StartManualTransferRuns instead.
1289 1290 1291 1292 1293 1294 1295 1296 1297 1298 1299 |
# File 'lib/google/apis/bigquerydatatransfer_v1/service.rb', line 1289 def schedule_project_transfer_config_runs(parent, schedule_transfer_runs_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+parent}:scheduleRuns', ) command.request_representation = Google::Apis::BigquerydatatransferV1::ScheduleTransferRunsRequest::Representation command.request_object = schedule_transfer_runs_request_object command.response_representation = Google::Apis::BigquerydatatransferV1::ScheduleTransferRunsResponse::Representation command.response_class = Google::Apis::BigquerydatatransferV1::ScheduleTransferRunsResponse command.params['parent'] = parent unless parent.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#start_project_location_transfer_config_manual_runs(parent, start_manual_transfer_runs_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigquerydatatransferV1::StartManualTransferRunsResponse
Manually initiates transfer runs. You can schedule these runs in two ways: 1. For a specific point in time using the 'requested_run_time' parameter. 2. For a period between 'start_time' (inclusive) and 'end_time' (exclusive). If scheduling a single run, it is set to execute immediately (schedule_time equals the current time). When scheduling multiple runs within a time range, the first run starts now, and subsequent runs are delayed by 15 seconds each.
814 815 816 817 818 819 820 821 822 823 824 |
# File 'lib/google/apis/bigquerydatatransfer_v1/service.rb', line 814 def start_project_location_transfer_config_manual_runs(parent, start_manual_transfer_runs_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+parent}:startManualRuns', ) command.request_representation = Google::Apis::BigquerydatatransferV1::StartManualTransferRunsRequest::Representation command.request_object = start_manual_transfer_runs_request_object command.response_representation = Google::Apis::BigquerydatatransferV1::StartManualTransferRunsResponse::Representation command.response_class = Google::Apis::BigquerydatatransferV1::StartManualTransferRunsResponse command.params['parent'] = parent unless parent.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#start_project_transfer_config_manual_runs(parent, start_manual_transfer_runs_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigquerydatatransferV1::StartManualTransferRunsResponse
Manually initiates transfer runs. You can schedule these runs in two ways: 1. For a specific point in time using the 'requested_run_time' parameter. 2. For a period between 'start_time' (inclusive) and 'end_time' (exclusive). If scheduling a single run, it is set to execute immediately (schedule_time equals the current time). When scheduling multiple runs within a time range, the first run starts now, and subsequent runs are delayed by 15 seconds each.
1331 1332 1333 1334 1335 1336 1337 1338 1339 1340 1341 |
# File 'lib/google/apis/bigquerydatatransfer_v1/service.rb', line 1331 def start_project_transfer_config_manual_runs(parent, start_manual_transfer_runs_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+parent}:startManualRuns', ) command.request_representation = Google::Apis::BigquerydatatransferV1::StartManualTransferRunsRequest::Representation command.request_object = start_manual_transfer_runs_request_object command.response_representation = Google::Apis::BigquerydatatransferV1::StartManualTransferRunsResponse::Representation command.response_class = Google::Apis::BigquerydatatransferV1::StartManualTransferRunsResponse command.params['parent'] = parent unless parent.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#unenroll_location_data_sources(name, unenroll_data_sources_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigquerydatatransferV1::Empty
Unenroll data sources in a user project. This allows users to remove transfer configurations for these data sources. They will no longer appear in the ListDataSources RPC and will also no longer appear in the BigQuery UI. Data transfers configurations of unenrolled data sources will not be scheduled.
352 353 354 355 356 357 358 359 360 361 362 |
# File 'lib/google/apis/bigquerydatatransfer_v1/service.rb', line 352 def unenroll_location_data_sources(name, unenroll_data_sources_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+name}:unenrollDataSources', ) command.request_representation = Google::Apis::BigquerydatatransferV1::UnenrollDataSourcesRequest::Representation command.request_object = unenroll_data_sources_request_object command.response_representation = Google::Apis::BigquerydatatransferV1::Empty::Representation command.response_class = Google::Apis::BigquerydatatransferV1::Empty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |