Class: Google::Apis::BigquerydatatransferV1::TransferResourceStatusDetail

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigquerydatatransfer_v1/classes.rb,
lib/google/apis/bigquerydatatransfer_v1/representations.rb,
lib/google/apis/bigquerydatatransfer_v1/representations.rb

Overview

Status details of the resource being transferred.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TransferResourceStatusDetail

Returns a new instance of TransferResourceStatusDetail.



1279
1280
1281
# File 'lib/google/apis/bigquerydatatransfer_v1/classes.rb', line 1279

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#completed_percentageFloat

Output only. Percentage of the transfer completed. Valid values: 0-100. Corresponds to the JSON property completedPercentage

Returns:

  • (Float)


1257
1258
1259
# File 'lib/google/apis/bigquerydatatransfer_v1/classes.rb', line 1257

def completed_percentage
  @completed_percentage
end

#errorGoogle::Apis::BigquerydatatransferV1::Status

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property error



1267
1268
1269
# File 'lib/google/apis/bigquerydatatransfer_v1/classes.rb', line 1267

def error
  @error
end

#stateString

Optional. Transfer state of the resource. Corresponds to the JSON property state

Returns:

  • (String)


1272
1273
1274
# File 'lib/google/apis/bigquerydatatransfer_v1/classes.rb', line 1272

def state
  @state
end

#summaryGoogle::Apis::BigquerydatatransferV1::TransferStatusSummary

Status summary of the resource being transferred. Corresponds to the JSON property summary



1277
1278
1279
# File 'lib/google/apis/bigquerydatatransfer_v1/classes.rb', line 1277

def summary
  @summary
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1284
1285
1286
1287
1288
1289
# File 'lib/google/apis/bigquerydatatransfer_v1/classes.rb', line 1284

def update!(**args)
  @completed_percentage = args[:completed_percentage] if args.key?(:completed_percentage)
  @error = args[:error] if args.key?(:error)
  @state = args[:state] if args.key?(:state)
  @summary = args[:summary] if args.key?(:summary)
end