Class: Google::Apis::BigquerydatatransferV1::TransferRun

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigquerydatatransfer_v1/classes.rb,
lib/google/apis/bigquerydatatransfer_v1/representations.rb,
lib/google/apis/bigquerydatatransfer_v1/representations.rb

Overview

Represents a data transfer run.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TransferRun

Returns a new instance of TransferRun.



1440
1441
1442
# File 'lib/google/apis/bigquerydatatransfer_v1/classes.rb', line 1440

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#data_source_idString

Output only. Data source id. Corresponds to the JSON property dataSourceId

Returns:

  • (String)


1345
1346
1347
# File 'lib/google/apis/bigquerydatatransfer_v1/classes.rb', line 1345

def data_source_id
  @data_source_id
end

#destination_dataset_idString

Output only. The BigQuery target dataset id. Corresponds to the JSON property destinationDatasetId

Returns:

  • (String)


1350
1351
1352
# File 'lib/google/apis/bigquerydatatransfer_v1/classes.rb', line 1350

def destination_dataset_id
  @destination_dataset_id
end

#email_preferencesGoogle::Apis::BigquerydatatransferV1::EmailPreferences

Represents preferences for sending email notifications for transfer run events. Corresponds to the JSON property emailPreferences



1355
1356
1357
# File 'lib/google/apis/bigquerydatatransfer_v1/classes.rb', line 1355

def email_preferences
  @email_preferences
end

#end_timeString

Output only. Time when transfer run ended. Parameter ignored by server for input requests. Corresponds to the JSON property endTime

Returns:

  • (String)


1361
1362
1363
# File 'lib/google/apis/bigquerydatatransfer_v1/classes.rb', line 1361

def end_time
  @end_time
end

#error_statusGoogle::Apis::BigquerydatatransferV1::Status

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property errorStatus



1371
1372
1373
# File 'lib/google/apis/bigquerydatatransfer_v1/classes.rb', line 1371

def error_status
  @error_status
end

#metadata_destinationGoogle::Apis::BigquerydatatransferV1::MetadataDestination

The metadata destination of the transfer config. Corresponds to the JSON property metadataDestination



1376
1377
1378
# File 'lib/google/apis/bigquerydatatransfer_v1/classes.rb', line 1376

def 
  @metadata_destination
end

#nameString

Identifier. The resource name of the transfer run. Transfer run names have the form projects/project_id/locations/location/transferConfigs/config_id/ runs/run_id`. The name is ignored when creating a transfer run. Corresponds to the JSON propertyname`

Returns:

  • (String)


1383
1384
1385
# File 'lib/google/apis/bigquerydatatransfer_v1/classes.rb', line 1383

def name
  @name
end

#notification_pubsub_topicString

Output only. Pub/Sub topic where a notification will be sent after this transfer run finishes. The format for specifying a pubsub topic is: projects/ project_id/topics/topic_id` Corresponds to the JSON propertynotificationPubsubTopic`

Returns:

  • (String)


1390
1391
1392
# File 'lib/google/apis/bigquerydatatransfer_v1/classes.rb', line 1390

def notification_pubsub_topic
  @notification_pubsub_topic
end

#paramsHash<String,Object>

Output only. Parameters specific to each data source. For more information see the bq tab in the 'Setting up a data transfer' section for each data source. For example the parameters for Cloud Storage transfers are listed here: https:/ /cloud.google.com/bigquery-transfer/docs/cloud-storage-transfer#bq Corresponds to the JSON property params

Returns:

  • (Hash<String,Object>)


1398
1399
1400
# File 'lib/google/apis/bigquerydatatransfer_v1/classes.rb', line 1398

def params
  @params
end

#run_timeString

For batch transfer runs, specifies the date and time of the data should be ingested. Corresponds to the JSON property runTime

Returns:

  • (String)


1404
1405
1406
# File 'lib/google/apis/bigquerydatatransfer_v1/classes.rb', line 1404

def run_time
  @run_time
end

#scheduleString

Output only. Describes the schedule of this transfer run if it was created as part of a regular schedule. For batch transfer runs that are scheduled manually, this is empty. NOTE: the system might choose to delay the schedule depending on the current load, so schedule_time doesn't always match this. Corresponds to the JSON property schedule

Returns:

  • (String)


1412
1413
1414
# File 'lib/google/apis/bigquerydatatransfer_v1/classes.rb', line 1412

def schedule
  @schedule
end

#schedule_timeString

Minimum time after which a transfer run can be started. Corresponds to the JSON property scheduleTime

Returns:

  • (String)


1417
1418
1419
# File 'lib/google/apis/bigquerydatatransfer_v1/classes.rb', line 1417

def schedule_time
  @schedule_time
end

#start_timeString

Output only. Time when transfer run was started. Parameter ignored by server for input requests. Corresponds to the JSON property startTime

Returns:

  • (String)


1423
1424
1425
# File 'lib/google/apis/bigquerydatatransfer_v1/classes.rb', line 1423

def start_time
  @start_time
end

#stateString

Data transfer run state. Ignored for input requests. Corresponds to the JSON property state

Returns:

  • (String)


1428
1429
1430
# File 'lib/google/apis/bigquerydatatransfer_v1/classes.rb', line 1428

def state
  @state
end

#update_timeString

Output only. Last time the data transfer run state was updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


1433
1434
1435
# File 'lib/google/apis/bigquerydatatransfer_v1/classes.rb', line 1433

def update_time
  @update_time
end

#user_idFixnum

Deprecated. Unique ID of the user on whose behalf transfer is done. Corresponds to the JSON property userId

Returns:

  • (Fixnum)


1438
1439
1440
# File 'lib/google/apis/bigquerydatatransfer_v1/classes.rb', line 1438

def user_id
  @user_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1445
1446
1447
1448
1449
1450
1451
1452
1453
1454
1455
1456
1457
1458
1459
1460
1461
1462
# File 'lib/google/apis/bigquerydatatransfer_v1/classes.rb', line 1445

def update!(**args)
  @data_source_id = args[:data_source_id] if args.key?(:data_source_id)
  @destination_dataset_id = args[:destination_dataset_id] if args.key?(:destination_dataset_id)
  @email_preferences = args[:email_preferences] if args.key?(:email_preferences)
  @end_time = args[:end_time] if args.key?(:end_time)
  @error_status = args[:error_status] if args.key?(:error_status)
  @metadata_destination = args[:metadata_destination] if args.key?(:metadata_destination)
  @name = args[:name] if args.key?(:name)
  @notification_pubsub_topic = args[:notification_pubsub_topic] if args.key?(:notification_pubsub_topic)
  @params = args[:params] if args.key?(:params)
  @run_time = args[:run_time] if args.key?(:run_time)
  @schedule = args[:schedule] if args.key?(:schedule)
  @schedule_time = args[:schedule_time] if args.key?(:schedule_time)
  @start_time = args[:start_time] if args.key?(:start_time)
  @state = args[:state] if args.key?(:state)
  @update_time = args[:update_time] if args.key?(:update_time)
  @user_id = args[:user_id] if args.key?(:user_id)
end