Class: Google::Apis::BigquerydatatransferV1::TransferRun
- Inherits:
-
Object
- Object
- Google::Apis::BigquerydatatransferV1::TransferRun
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/bigquerydatatransfer_v1/classes.rb,
lib/google/apis/bigquerydatatransfer_v1/representations.rb,
lib/google/apis/bigquerydatatransfer_v1/representations.rb
Overview
Represents a data transfer run.
Instance Attribute Summary collapse
-
#data_source_id ⇒ String
Output only.
-
#destination_dataset_id ⇒ String
Output only.
-
#email_preferences ⇒ Google::Apis::BigquerydatatransferV1::EmailPreferences
Represents preferences for sending email notifications for transfer run events.
-
#end_time ⇒ String
Output only.
-
#error_status ⇒ Google::Apis::BigquerydatatransferV1::Status
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. -
#name ⇒ String
Identifier.
-
#notification_pubsub_topic ⇒ String
Output only.
-
#params ⇒ Hash<String,Object>
Output only.
-
#run_time ⇒ String
For batch transfer runs, specifies the date and time of the data should be ingested.
-
#schedule ⇒ String
Output only.
-
#schedule_time ⇒ String
Minimum time after which a transfer run can be started.
-
#start_time ⇒ String
Output only.
-
#state ⇒ String
Data transfer run state.
-
#update_time ⇒ String
Output only.
-
#user_id ⇒ Fixnum
Deprecated.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TransferRun
constructor
A new instance of TransferRun.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TransferRun
Returns a new instance of TransferRun.
1389 1390 1391 |
# File 'lib/google/apis/bigquerydatatransfer_v1/classes.rb', line 1389 def initialize(**args) update!(**args) end |
Instance Attribute Details
#data_source_id ⇒ String
Output only. Data source id.
Corresponds to the JSON property dataSourceId
1299 1300 1301 |
# File 'lib/google/apis/bigquerydatatransfer_v1/classes.rb', line 1299 def data_source_id @data_source_id end |
#destination_dataset_id ⇒ String
Output only. The BigQuery target dataset id.
Corresponds to the JSON property destinationDatasetId
1304 1305 1306 |
# File 'lib/google/apis/bigquerydatatransfer_v1/classes.rb', line 1304 def destination_dataset_id @destination_dataset_id end |
#email_preferences ⇒ Google::Apis::BigquerydatatransferV1::EmailPreferences
Represents preferences for sending email notifications for transfer run events.
Corresponds to the JSON property emailPreferences
1309 1310 1311 |
# File 'lib/google/apis/bigquerydatatransfer_v1/classes.rb', line 1309 def email_preferences @email_preferences end |
#end_time ⇒ String
Output only. Time when transfer run ended. Parameter ignored by server for
input requests.
Corresponds to the JSON property endTime
1315 1316 1317 |
# File 'lib/google/apis/bigquerydatatransfer_v1/classes.rb', line 1315 def end_time @end_time end |
#error_status ⇒ Google::Apis::BigquerydatatransferV1::Status
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property errorStatus
1325 1326 1327 |
# File 'lib/google/apis/bigquerydatatransfer_v1/classes.rb', line 1325 def error_status @error_status end |
#name ⇒ String
Identifier. The resource name of the transfer run. Transfer run names have the
form projects/project_id/locations/location/transferConfigs/config_id/
runs/run_id`. The name is ignored when creating a transfer run.
Corresponds to the JSON propertyname`
1332 1333 1334 |
# File 'lib/google/apis/bigquerydatatransfer_v1/classes.rb', line 1332 def name @name end |
#notification_pubsub_topic ⇒ String
Output only. Pub/Sub topic where a notification will be sent after this
transfer run finishes. The format for specifying a pubsub topic is: projects/
project_id/topics/topic_id`
Corresponds to the JSON propertynotificationPubsubTopic`
1339 1340 1341 |
# File 'lib/google/apis/bigquerydatatransfer_v1/classes.rb', line 1339 def notification_pubsub_topic @notification_pubsub_topic end |
#params ⇒ Hash<String,Object>
Output only. Parameters specific to each data source. For more information see
the bq tab in the 'Setting up a data transfer' section for each data source.
For example the parameters for Cloud Storage transfers are listed here: https:/
/cloud.google.com/bigquery-transfer/docs/cloud-storage-transfer#bq
Corresponds to the JSON property params
1347 1348 1349 |
# File 'lib/google/apis/bigquerydatatransfer_v1/classes.rb', line 1347 def params @params end |
#run_time ⇒ String
For batch transfer runs, specifies the date and time of the data should be
ingested.
Corresponds to the JSON property runTime
1353 1354 1355 |
# File 'lib/google/apis/bigquerydatatransfer_v1/classes.rb', line 1353 def run_time @run_time end |
#schedule ⇒ String
Output only. Describes the schedule of this transfer run if it was created as
part of a regular schedule. For batch transfer runs that are scheduled
manually, this is empty. NOTE: the system might choose to delay the schedule
depending on the current load, so schedule_time doesn't always match this.
Corresponds to the JSON property schedule
1361 1362 1363 |
# File 'lib/google/apis/bigquerydatatransfer_v1/classes.rb', line 1361 def schedule @schedule end |
#schedule_time ⇒ String
Minimum time after which a transfer run can be started.
Corresponds to the JSON property scheduleTime
1366 1367 1368 |
# File 'lib/google/apis/bigquerydatatransfer_v1/classes.rb', line 1366 def schedule_time @schedule_time end |
#start_time ⇒ String
Output only. Time when transfer run was started. Parameter ignored by server
for input requests.
Corresponds to the JSON property startTime
1372 1373 1374 |
# File 'lib/google/apis/bigquerydatatransfer_v1/classes.rb', line 1372 def start_time @start_time end |
#state ⇒ String
Data transfer run state. Ignored for input requests.
Corresponds to the JSON property state
1377 1378 1379 |
# File 'lib/google/apis/bigquerydatatransfer_v1/classes.rb', line 1377 def state @state end |
#update_time ⇒ String
Output only. Last time the data transfer run state was updated.
Corresponds to the JSON property updateTime
1382 1383 1384 |
# File 'lib/google/apis/bigquerydatatransfer_v1/classes.rb', line 1382 def update_time @update_time end |
#user_id ⇒ Fixnum
Deprecated. Unique ID of the user on whose behalf transfer is done.
Corresponds to the JSON property userId
1387 1388 1389 |
# File 'lib/google/apis/bigquerydatatransfer_v1/classes.rb', line 1387 def user_id @user_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1394 1395 1396 1397 1398 1399 1400 1401 1402 1403 1404 1405 1406 1407 1408 1409 1410 |
# File 'lib/google/apis/bigquerydatatransfer_v1/classes.rb', line 1394 def update!(**args) @data_source_id = args[:data_source_id] if args.key?(:data_source_id) @destination_dataset_id = args[:destination_dataset_id] if args.key?(:destination_dataset_id) @email_preferences = args[:email_preferences] if args.key?(:email_preferences) @end_time = args[:end_time] if args.key?(:end_time) @error_status = args[:error_status] if args.key?(:error_status) @name = args[:name] if args.key?(:name) @notification_pubsub_topic = args[:notification_pubsub_topic] if args.key?(:notification_pubsub_topic) @params = args[:params] if args.key?(:params) @run_time = args[:run_time] if args.key?(:run_time) @schedule = args[:schedule] if args.key?(:schedule) @schedule_time = args[:schedule_time] if args.key?(:schedule_time) @start_time = args[:start_time] if args.key?(:start_time) @state = args[:state] if args.key?(:state) @update_time = args[:update_time] if args.key?(:update_time) @user_id = args[:user_id] if args.key?(:user_id) end |